Module: Google::Ads::MarketingPlatform::Admin

Defined in:
lib/google/ads/marketing_platform/admin.rb,
lib/google/ads/marketing_platform/admin/version.rb

Constant Summary collapse

VERSION =
"0.3.0"

Class Method Summary collapse

Class Method Details

.marketingplatform_admin_service(version: :v1alpha, transport: :grpc, &block) ⇒ ::Object

Create a new client object for MarketingplatformAdminService.

By default, this returns an instance of Google::Ads::MarketingPlatform::Admin::V1alpha::MarketingplatformAdminService::Client for a gRPC client for version V1alpha of the API. However, you can specify a different API version by passing it in the version parameter. If the MarketingplatformAdminService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the MarketingplatformAdminService service. You can determine whether the method will succeed by calling marketingplatform_admin_service_available?.

About MarketingplatformAdminService

Service Interface for the Google Marketing Platform Admin API.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1alpha)

    The API version to connect to. Optional. Defaults to :v1alpha.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/google/ads/marketing_platform/admin.rb', line 58

def self.marketingplatform_admin_service version: :v1alpha, transport: :grpc, &block
  require "google/ads/marketing_platform/admin/#{version.to_s.downcase}"

  package_name = Google::Ads::MarketingPlatform::Admin
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Ads::MarketingPlatform::Admin.const_get(package_name).const_get(:MarketingplatformAdminService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.marketingplatform_admin_service_available?(version: :v1alpha, transport: :grpc) ⇒ boolean

Determines whether the MarketingplatformAdminService service is supported by the current client. If true, you can retrieve a client object by calling marketingplatform_admin_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the MarketingplatformAdminService service, or if the versioned client gem needs an update to support the MarketingplatformAdminService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1alpha)

    The API version to connect to. Optional. Defaults to :v1alpha.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/google/ads/marketing_platform/admin.rb', line 82

def self.marketingplatform_admin_service_available? version: :v1alpha, transport: :grpc
  require "google/ads/marketing_platform/admin/#{version.to_s.downcase}"
  package_name = Google::Ads::MarketingPlatform::Admin
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Ads::MarketingPlatform::Admin.const_get package_name
  return false unless service_module.const_defined? :MarketingplatformAdminService
  service_module = service_module.const_get :MarketingplatformAdminService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end